# -*- coding: utf-8 -*-
from typing import Any, Dict, Optional

import pygismeteo_base
from requests import Session

from pygismeteo._exceptions import LocalityNotFound


class Gismeteo:
    def __init__(
        self,
        *,
        lang: pygismeteo_base.types.LANG = "ru",
        token: str = pygismeteo_base.constants.DEFAULT_TOKEN,
        session: Optional[Session] = None,
    ) -> None:
        self.lang = lang.strip()
        self.token = token.strip()
        self._session = session

    def current(self, id: int) -> pygismeteo_base.models.current.Model:
        return pygismeteo_base.models.current.Model.parse_obj(
            self._get_response(f"weather/current/{id}")
        )

    def step3(
        self, id: int, days: pygismeteo_base.types.STEP3_DAYS
    ) -> pygismeteo_base.models.step3or6.Model:
        return pygismeteo_base.models.step3or6.Model.parse_obj(
            self._get_response(f"weather/forecast/{id}", {"days": str(days)})
        )

    def step6(
        self, id: int, days: pygismeteo_base.types.DAYS
    ) -> pygismeteo_base.models.step3or6.Model:
        return pygismeteo_base.models.step3or6.Model.parse_obj(
            self._get_response(
                f"weather/forecast/by_day_part/{id}", {"days": str(days)}
            )
        )

    def step24(
        self, id: int, days: pygismeteo_base.types.DAYS
    ) -> pygismeteo_base.models.step24.Model:
        return pygismeteo_base.models.step24.Model.parse_obj(
            self._get_response(
                f"weather/forecast/aggregate/{id}", {"days": str(days)}
            )
        )

    def get_id_by_query(self, query: str) -> int:
        items = self._get_response("search/cities", {"query": query})["items"]
        if not items:
            raise LocalityNotFound("Населённый пункт не найден.")
        return int(items[0]["id"])

    def _fetch(
        self, endpoint: str, params: Optional[Dict[str, str]], session: Session
    ) -> Any:
        with session.get(
            f"https://api.gismeteo.net/v2/{endpoint}",
            params={"lang": self.lang, **(params or {})},
            headers={"X-Gismeteo-Token": self.token},
        ) as r:
            r.raise_for_status()
            return r.json()

    def _get_json(
        self, endpoint: str, params: Optional[Dict[str, str]] = None
    ) -> Any:
        if isinstance(self._session, Session):
            return self._fetch(endpoint, params, self._session)
        with Session() as session:
            return self._fetch(endpoint, params, session)

    def _get_response(
        self, endpoint: str, params: Optional[Dict[str, str]] = None
    ) -> Any:
        return self._get_json(endpoint, params)["response"]



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['pygismeteo']

package_data = \
{'': ['*']}

install_requires = \
['pygismeteo-base>=2.1.0,<3.0.0', 'requests>=2.25.1,<3.0.0']

setup_kwargs = {
    'name': 'pygismeteo',
    'version': '4.0.0',
    'description': 'Wrapper for Gismeteo.ru API',
    'long_description': '# pygismeteo\n\n[![Build Status](https://github.com/monosans/pygismeteo/workflows/test/badge.svg?branch=main&event=push)](https://github.com/monosans/pygismeteo/actions?query=workflow%3Atest)\n[![codecov](https://codecov.io/gh/monosans/pygismeteo/branch/main/graph/badge.svg)](https://codecov.io/gh/monosans/pygismeteo)\n[![Python Version](https://img.shields.io/pypi/pyversions/pygismeteo.svg)](https://pypi.org/project/pygismeteo/)\n[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://github.com/monosans/pygismeteo/blob/main/LICENSE)\n\nОбёртка для [Gismeteo.ru API](https://gismeteo.ru/api).\n\nАсинхронная версия [здесь](https://github.com/monosans/aiopygismeteo).\n\n## Установка\n\n```bash\npython -m pip install -U pygismeteo\n```\n\n## Документация\n\nРелизная версия - <https://pygismeteo.readthedocs.io>\n\nGit версия - <https://pygismeteo.readthedocs.io/ru/latest>\n\n## Пример, выводящий температуру в Москве сейчас\n\n```python\nfrom pygismeteo import Gismeteo\n\ngm = Gismeteo()\ncity_id = gm.get_id_by_query("Москва")\ncurrent = gm.current(city_id)\nprint(current.temperature.air.c)\n```\n',
    'author': 'monosans',
    'author_email': 'hsyqixco@protonmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/monosans/pygismeteo',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6.2,<4.0.0',
}


setup(**setup_kwargs)
